pub struct Location<Name> {
pub descendant: Name,
pub distance: u64,
}Expand description
The position of one node in the graph relative their known descendant.
This structure is relevant when the IdMap is lazy. Assuming that all parents of merges
and all heads are known then any node can be represented as their first descendant
and the distance to that descendant.
Example:
0 - a - b - c
In this example our initial commit is 0, then we have a the first commit, b second,
c third.
{
descendant: c,
distance: 1,
}
=> [b]
Fields
descendant: Namedistance: u64Implementations
Sourceimpl<Name> Location<Name>
impl<Name> Location<Name>
pub fn new(descendant: Name, distance: u64) -> Self
pub fn map_descendant<T, F>(self, f: F) -> Location<T>where
F: FnOnce(Name) -> T,
pub fn try_map_descendant<T, E, F>(self, f: F) -> Result<Location<T>, E>
pub async fn then_descendant<T, Fut, F>(self, f: F) -> Location<T>
pub async fn and_then_descendant<T, E, Fut, F>( self, f: F, ) -> Result<Location<T>, E>
pub fn with_descendant<T>(self, descendant: T) -> Location<T>