pub struct PreparedFlatSegments {
pub segments: BTreeSet<FlatSegment>,
}Expand description
These segments can be used directly in the build process of the IdDag.
They produced by IdMap::assign_head and IdDag::all_flat_segments.
Fields
segments: BTreeSet<FlatSegment>New flat segments.
Implementations
Sourceimpl PreparedFlatSegments
impl PreparedFlatSegments
pub fn vertex_count(&self) -> u64
pub fn segment_count(&self) -> usize
Sourcepub fn parents_head_and_roots(&self) -> BTreeSet<Id>
pub fn parents_head_and_roots(&self) -> BTreeSet<Id>
Return set of all (unique) parents + head + roots of flat segments.
Used by the pull fast path to provide necessary “anchor” vertexes (“universally known”, and ones needed by the client to make decisions) in the IdMap.
Might return some extra Ids that are not part of parents, heads, or
roots. They are useful for the client to verify the graph is the same
as the server.
The size of the returned Ids is about O(segments).