Group

Struct Group 

pub struct Group(pub usize);
An integer that separates distinct groups of Ids.

This can be seen as a way to pre-allocate consecutive integers for one group to make segments less fragmented.

(Group, Id) are also topologically sorted.

Tuple Fields

0: usize

Implementations

Source

impl Group

pub const MASTER: Self

The “master” group. usually ancestors(master).

  • Expected to have most of the commits in a repo.
  • Ideally free from fragmentation. In other words, ancestors(master) can be represented in a single Span.
  • Ideally has limited heads. Does not scale with too many heads.
  • Vertexs (commit hashes) might be lazy.
pub const NON_MASTER: Self

The “non-master” group.

  • Concrete vertexes not in the “master” group. For example, public release branches, local feature branches.
  • Expected to have multiple heads. In other words, is fragmented.
  • Expected to be sparse referred. For example, the “visible heads” will refer to a bounded subset in this group.
  • Expected to be non-lazy. Code paths assume Vertexs (commit hashes) are known in this group.
pub const VIRTUAL: Self

The “virtual” group.

  • Typically, “null” and “wdir()”.
  • Should not be written to disk.
  • Not lazy.
pub const PERSIST: [Self; 2]

Groups designed to be persisted to disk.

pub const ALL: [Self; 3]

pub const MAX: Self

pub const COUNT: usize

pub const BITS: u32 = 8

pub const BYTES: usize = 1

pub const fn min_id(self) -> Id

The first Id in this group.

pub const fn max_id(self) -> Id

The maximum Id in this group.

pub const fn bytes(self) -> [u8; 1]

Convert to array.

pub fn hex_bytes(self) -> [u8; 2]

Convert to hex array.

pub fn is_valid(self) -> bool

Test if the Group is valid.